=======
History
=======

0.2.2 (2018-03-28)
------------------
* Fixed Python2 compatibility error (#35)

0.2.1 (2018-03-11)
------------------
* Added item to YapconfItemNotFound (#21)
* Removed pytest-runner from setup_reuires (#22)

0.2.0 (2018-03-11)
------------------

* Added auto kebab-case for CLI arguments (#7)
* Added the flag to apply environment prefixes (#11)
* Added ``choices`` to item specification (#14)
* Added ``alt_env_names`` to item specification (#13)

0.1.1 (2018-02-08)
------------------

* Fixed bug where ``None`` was a respected value.

0.1.0 (2018-02-01)
------------------

* First release on PyPI.
